#!/bin/bash
#Description: DevKit constants
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2023. All rights reserved.
#History: 2024-01-10 created

RETURN_SUCCESS='SUCCESS'

function init_variables {
    mpi_app_dir_path=$(dirname ${mpi_app_path})
    kunpeng_dir_path=${mpi_app_dir_path}/kunpeng
    uuid_dir_path=${kunpeng_dir_path}/${user_uuid}
    encrypt_path=${uuid_dir_path}/hercules
    key_passwd_path=${install_path}/rpc_cert
    DEVKIT_BIN="/usr/bin/devkit"
    DEBUGGER_ENTRANCE_PATH="$debugger_entrance_path"
}



function force_mk_dir()
{
    local dir=$1
    if [ -d "${dir}" ]; then
        rm -rf "${dir}"
    fi
    mkdir -p "${dir}"
}


function create_relative_dirs() {
    force_mk_dir ${kunpeng_dir_path}
    chmod -R 700 ${kunpeng_dir_path}

    force_mk_dir ${uuid_dir_path}
    chmod -R 700 ${uuid_dir_path}
}

function copy_debugger_libs() {
    cp -f ${DEBUGGER_ENTRANCE_PATH}/agent.tar.gz ${uuid_dir_path}
    cd ${uuid_dir_path}
    tar -zxf ${uuid_dir_path}/agent.tar.gz
    chmod 500 ${uuid_dir_path}/agent.tar.gz
    cp -f ${DEBUGGER_ENTRANCE_PATH}/libkmpi.so ${uuid_dir_path}
    chmod 400 ${uuid_dir_path}/libkmpi.so
    if [ $mode == "web" ]; then
        cp -f ${DEBUGGER_ENTRANCE_PATH}/libstdc++.so.6.0.28 ${uuid_dir_path}/libstdc++.so
    else
        cp -f ${install_path}/_internal/libstdc++.so.6.0.28 ${uuid_dir_path}/libstdc++.so
    fi
    chmod 400 ${uuid_dir_path}/libstdc++.so
    cp -f ${DEBUGGER_ENTRANCE_PATH}/lldb-server ${uuid_dir_path}
    chmod 500 ${uuid_dir_path}/lldb-server
    cp -f ${DEBUGGER_ENTRANCE_PATH}/agent.tar.gz ${uuid_dir_path}
    chmod 500 ${uuid_dir_path}/agent.tar.gz
    chmod -R 700 ${uuid_dir_path}/agent
    if [ $mode != "web" ]; then
        cp -f ${DEBUGGER_ENTRANCE_PATH}/libdevkit_crypto.so ${uuid_dir_path}
        chmod 500 ${uuid_dir_path}/libdevkit_crypto.so
    fi
}

function mkdir_encrypt_path() {
    force_mk_dir ${encrypt_path}
    common_path=${encrypt_path}/common
    force_mk_dir ${common_path}
    greece_path=${common_path}/greece
    force_mk_dir ${greece_path}
    nordic_path=${common_path}/nordic
    force_mk_dir ${nordic_path}
    rome_path=${common_path}/rome
    force_mk_dir ${rome_path}
    chmod -R 700 ${encrypt_path}
}

function copy_encrypt_message() {
    force_mk_dir ${encrypt_path}
    cp -f ${key_passwd_path}/debugger_ca.pem ${encrypt_path}
    cp -f ${key_passwd_path}/debugger_client.pem ${encrypt_path}
    cp -f ${key_passwd_path}/client.key ${encrypt_path}
    cp -rf ${key_passwd_path}/client_passwd ${encrypt_path}
    find "${encrypt_path}" -type d -exec chmod 700 {} \;
    find "${encrypt_path}" -type f -exec chmod 600 {} \;
}

function copy_debugger_bin_path() {
    force_mk_dir ${DEBUGGER_ENTRANCE_PATH}/temp/${user_uuid}
    cp ${mpi_app_path} ${DEBUGGER_ENTRANCE_PATH}/temp/${user_uuid}/
    chmod -R 755 ${DEBUGGER_ENTRANCE_PATH}/temp/${user_uuid}
}

function process_encrypt_files() {
    if [ $mode == "web" ]; then
        mkdir_encrypt_path
    else
        copy_encrypt_message
    fi
}

function main() {
    user_uuid="$1"
    mpi_app_path="$2"
    mpi_source_path="$3"
    install_path="$4"
    mode="$5"
    debugger_entrance_path="$6"
    init_variables
    create_relative_dirs
    copy_debugger_libs
    process_encrypt_files
    copy_debugger_bin_path
    echo ${RETURN_SUCCESS}
}

main "$@"
